# functionname { #vscodenb.modulename.functionname }

```python
vscodenb.modulename.functionname(x=1, y=1)
```

The sum of two numbers.

## Parameters {.doc-section .doc-section-parameters}

<code>[**x**]{.parameter-name} [:]{.parameter-annotation-sep} [[int](`int`)]{.parameter-annotation} [ = ]{.parameter-default-sep} [1]{.parameter-default}</code>

:   The first number

<code>[**y**]{.parameter-name} [:]{.parameter-annotation-sep} [[int](`int`)]{.parameter-annotation} [ = ]{.parameter-default-sep} [1]{.parameter-default}</code>

:   The second number.

## Returns {.doc-section .doc-section-returns}

<code>[]{.parameter-name} [:]{.parameter-annotation-sep} [[int](`int`)]{.parameter-annotation}</code>

:   Sum of two numbers.

## Examples {.doc-section .doc-section-examples}

Adding two numbers

```python
result = foo(2, 4)
```

## See Also {.doc-section .doc-section-see-also}

[](`libraryname.modulename.scriptname`)